diff --git a/docs/manual/clonevm.html b/docs/manual/clonevm.html
index 2a2ceb4c6..a595faee0 100644
--- a/docs/manual/clonevm.html
+++ b/docs/manual/clonevm.html
@@ -2,16 +2,16 @@
-build.clonevm
+ant.build.clonevm
-
+
Since Ant 1.7
-The value of the build.clonevm system property controls how Ant
+
The value of the ant.build.clonevm system property controls how Ant
instruments forked Java Virtual Machines. The java and junit tasks support clonevm
@@ -20,7 +20,7 @@ property applies to all forked Java VMs.
If the value of the property is true, then all system properties of
the forked Java Virtual Machine will be the same as those of the Java
-VM running Ant. In addition, if you set build.clonevm to true and build.sysclasspath has not been set, the
bootclasspath of forked Java VMs gets constructed as if
build.sysclasspath had the value "last".
diff --git a/docs/manual/conceptstypeslist.html b/docs/manual/conceptstypeslist.html
index 41cc73f14..bc2677504 100644
--- a/docs/manual/conceptstypeslist.html
+++ b/docs/manual/conceptstypeslist.html
@@ -11,7 +11,7 @@
Concepts
-build.clonevm
+ant.build.clonevm
build.sysclasspath
Common Attributes
diff --git a/src/testcases/org/apache/tools/ant/types/CommandlineJavaTest.java b/src/testcases/org/apache/tools/ant/types/CommandlineJavaTest.java
index fd0f864a5..62eee9f16 100644
--- a/src/testcases/org/apache/tools/ant/types/CommandlineJavaTest.java
+++ b/src/testcases/org/apache/tools/ant/types/CommandlineJavaTest.java
@@ -1,5 +1,5 @@
/*
- * Copyright 2000-2004 The Apache Software Foundation
+ * Copyright 2000-2005 The Apache Software Foundation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -39,15 +39,15 @@ public class CommandlineJavaTest extends TestCase {
project = new Project();
project.setBasedir(System.getProperty("root"));
project.setProperty("build.sysclasspath", "ignore");
- cloneVm = System.getProperty("build.clonevm");
+ cloneVm = System.getProperty("ant.build.clonevm");
if (cloneVm != null) {
- System.setProperty("build.clonevm", "false");
+ System.setProperty("ant.build.clonevm", "false");
}
}
public void tearDown() {
if (cloneVm != null) {
- System.setProperty("build.clonevm", cloneVm);
+ System.setProperty("ant.build.clonevm", cloneVm);
}
}
diff --git a/src/main/org/apache/tools/ant/types/CommandlineJava.java b/src/main/org/apache/tools/ant/types/CommandlineJava.java
index 2832ab0ed..8c2aad8c5 100644
--- a/src/main/org/apache/tools/ant/types/CommandlineJava.java
+++ b/src/main/org/apache/tools/ant/types/CommandlineJava.java
@@ -640,7 +640,7 @@ public class CommandlineJava implements Cloneable {
/**
* Calculate the bootclasspath based on the bootclasspath
* specified, the build.sysclasspath and build.clonevm magic
* properties as well as the cloneVm attribute.
*
* @since Ant 1.7
@@ -664,11 +664,13 @@ public class CommandlineJava implements Cloneable {
}
/**
* Has the cloneVm attribute or the magic property build.clonevm been set?
*
* @since 1.7
*/
private boolean isCloneVm() {
- return cloneVm || "true".equals(System.getProperty("build.clonevm"));
+ return cloneVm
+ || "true".equals(System.getProperty("ant.build.clonevm"));
}
}
@@ -640,7 +640,7 @@ public class CommandlineJava implements Cloneable {
/**
* Calculate the bootclasspath based on the bootclasspath
- * specified, the build.sysclasspath and build.clonevm magic
+ * specified, the build.sysclasspath and ant.build.clonevm magic
* properties as well as the cloneVm attribute.
*
@@ -664,11 +664,13 @@ public class CommandlineJava implements Cloneable {
}
/**
- * Has the cloneVm attribute or the magic property build.clonevm been set?
+ * Has the cloneVm attribute or the magic property
+ * ant.build.clonevm been set?
*
* @since 1.7